==> nomachine-8.9.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXDbusMonitor.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXDbusMonitor;no warnings;require Common::NXShellCommands;require NXDbus
;($monitoringMode_noDbus="\x5f\x5f\x6e\x6f\x44\x42\x75\x73\x5f\x5f");(
$monitoringMode_CK=
"\x6f\x72\x67\x2e\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2e\x43\x6f\x6e\x73\x6f\x6c\x65\x4b\x69\x74"
);($monitoringMode_GDM=
"\x6f\x72\x67\x2e\x67\x6e\x6f\x6d\x65\x2e\x44\x69\x73\x70\x6c\x61\x79\x4d\x61\x6e\x61\x67\x65\x72"
);($monitoringMode_FDM=
"\x6f\x72\x67\x2e\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2e\x44\x69\x73\x70\x6c\x61\x79\x4d\x61\x6e\x61\x67\x65\x72"
);($monitoringMode_LOG=
"\x6f\x72\x67\x2e\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2e\x6c\x6f\x67\x69\x6e\x31"
);($event_sessionAdded="\x53\x65\x73\x73\x69\x6f\x6e\x41\x64\x64\x65\x64");(
$event_sessionRemoved="\x53\x65\x73\x73\x69\x6f\x6e\x52\x65\x6d\x6f\x76\x65\x64"
);($event_activeSessionChanged=
"\x41\x63\x74\x69\x76\x65\x53\x65\x73\x73\x69\x6f\x6e\x43\x68\x61\x6e\x67\x65\x64"
);($monitoringMode=(""));($stdout=(-(0x0f66+ 4159-0x1fa4)));($stdin=(-
(0x09dd+ 261-0x0ae1)));($started=(0x03c6+ 4566-0x159c));($pid=
(0x2093+ 556-0x22bf));($currentEvent=(""));sub startMonitor{if ((not (
isDbusEnabledByConfig ()))){Logger::debug (
"\x44\x42\x75\x73\x20\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x69\x73\x20\x64\x69\x73\x61\x62\x6c\x65\x64\x2e"
);return ((0x0744+ 4632-0x195c));}if ($started){return ((0x00d0+ 3414-0x0e26));}
if (($monitoringMode eq (""))){if ((not (selectMonitoringMode ()))){
Logger::debug (
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x3a\x20\x6e\x6f\x20\x62\x75\x73\x20\x73\x75\x69\x74\x61\x62\x6c\x65\x20\x66\x6f\x72\x20\x6d\x6f\x6e\x69\x74\x6f\x72\x69\x6e\x67\x20\x66\x6f\x75\x6e\x64\x2e"
);return ((0x03f3+ 1514-0x09dd));}}Logger::debug (
"\x53\x74\x61\x72\x74\x69\x6e\x67\x20\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x2e"
);my ($dbusIn);my ($dbusOut);Common::NXCore::nxPipeCreateBi ((\$stdin),(\$dbusIn
));Common::NXCore::nxPipeCreateBi ((\$stdout),(\$dbusOut));if (($monitoringMode 
eq $monitoringMode_CK)){($pid=NXDbus::dbusMonitor ($dbusIn,$dbusOut,
"\x73\x79\x73\x74\x65\x6d","\x73\x69\x67\x6e\x61\x6c",(""),
"\x6f\x72\x67\x2e\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2e\x43\x6f\x6e\x73\x6f\x6c\x65\x4b\x69\x74\x2e\x53\x65\x61\x74"
,("")));}elsif (($monitoringMode eq $monitoringMode_GDM)){($pid=
NXDbus::dbusMonitor ($dbusIn,$dbusOut,"\x73\x79\x73\x74\x65\x6d",
"\x6d\x65\x74\x68\x6f\x64\x5f\x63\x61\x6c\x6c",(""),
"\x6f\x72\x67\x2e\x67\x6e\x6f\x6d\x65\x2e\x44\x69\x73\x70\x6c\x61\x79\x4d\x61\x6e\x61\x67\x65\x72\x2e\x4d\x61\x6e\x61\x67\x65\x72"
,"\x52\x65\x67\x69\x73\x74\x65\x72\x53\x65\x73\x73\x69\x6f\x6e"));}elsif ((
$monitoringMode eq $monitoringMode_FDM)){($pid=NXDbus::dbusMonitor ($dbusIn,
$dbusOut,"\x73\x79\x73\x74\x65\x6d","\x73\x69\x67\x6e\x61\x6c",(""),
"\x6f\x72\x67\x2e\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2e\x44\x69\x73\x70\x6c\x61\x79\x4d\x61\x6e\x61\x67\x65\x72"
,("")));}elsif (($monitoringMode eq $monitoringMode_LOG)){($pid=
NXDbus::dbusMonitor ($dbusIn,$dbusOut,"\x73\x79\x73\x74\x65\x6d",
"\x73\x69\x67\x6e\x61\x6c",(""),
"\x6f\x72\x67\x2e\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2e\x6c\x6f\x67\x69\x6e\x31\x2e\x4d\x61\x6e\x61\x67\x65\x72"
,("")));}if (($pid>(0x1275+ 799-0x1594))){($started=(0x02c1+ 7967-0x21df));
Logger::debug (((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x72\x75\x6e\x6e\x69\x6e\x67\x20\x77\x69\x74\x68\x20\x50\x49\x44\x20"
.$pid)."\x2e"));return ((0x006b+ 3815-0x0f51));}else{Logger::debug (
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6e\x6f\x74\x20\x73\x74\x61\x72\x74\x65\x64\x2e"
);return ((0x0bb9+ 3719-0x1a40));}}sub getStdout{return ($stdout);}sub isRunning
{return ($started);}sub stopMonitor{Logger::debug (
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x73\x74\x6f\x70\x4d\x6f\x6e\x69\x74\x6f\x72\x2e"
);if (isRunning ()){Logger::debug (((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x73\x65\x6e\x64\x69\x6e\x67\x20\x73\x69\x67\x74\x65\x72\x6d\x20\x74\x6f\x20\x70\x72\x6f\x63\x65\x73\x73\x20\x77\x69\x74\x68\x20\x70\x69\x64\x20\x27"
.$pid)."\x27\x2e"));Common::NXProcess::signalProcessByRestrictedScript ($pid,
Common::NXProcess::getSignalTerm ());if ((Common::NXProcess::nxwaitpid ($pid,
$NXBits::WAIT_UNTRACED,(0x03b9+ 7261-0x2011))==$pid)){($pid=(-
(0x0fdb+ 5632-0x25da)));($started=(0x091d+ 3869-0x183a));}else{
Common::NXProcess::signalProcessByRestrictedScript ($pid,
Common::NXProcess::getSignalKill ());if ((Common::NXProcess::nxwaitpid ($pid,
$NXBits::WAIT_UNTRACED,(0x0af1+ 2802-0x15de))==$pid)){($pid=(-
(0x0a3d+ 4605-0x1c39)));($started=(0x035b+ 5712-0x19ab));}}}}sub 
parseDbusMonitorBuffer{(my $buffer=shift (@_));(my (@lines)=split ( /\n/ ,
$buffer,(0x01f1+ 2165-0x0a66)));foreach my $line (@lines){parseDbusMonitorLine (
$line);}}sub parseDbusMonitorLine{(my $line=shift (@_));Logger::debug (((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x70\x61\x72\x73\x65\x20\x6c\x69\x6e\x65\x20\x27"
.$line)."\x27\x2e"));if (($monitoringMode eq $monitoringMode_CK)){
parseDbusMonitorLine_CK ($line);}elsif (($monitoringMode eq $monitoringMode_LOG)
){parseDbusMonitorLine_LOG ($line);}else{if (($line=~ /member=SessionRemoved/ ))
{PhysicSessions::forceCheck ();}elsif (($line=~ /member=SessionAdded/ )){
PhysicSessions::forceCheck ();}elsif (($line=~ /RegisterSession/ )){
PhysicSessions::forceCheck ();}elsif (($line=~ /object path "(.*)"/ )){(my $objectPath
=$1);Logger::debug (((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6f\x62\x6a\x65\x63\x74\x20\x70\x61\x74\x68\x20\x66\x6f\x72\x20\x65\x76\x65\x6e\x74\x20\x27"
.$objectPath)."\x27\x2e"));}}}sub parseDbusMonitorLine_CK{(my $line=shift (@_));
if (($line=~ /member=SessionAdded/ )){PhysicSessions::forceCheck ();}elsif ((
$line=~ /member=SessionRemoved/ )){PhysicSessions::forceCheck ();}elsif (($line
=~ /member=ActiveSessionChanged/ )){PhysicSessions::forceCheck ();}elsif (($line
=~ /object path "(.*)"/ )){(my $objectPath=$1);Logger::debug (((((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6f\x62\x6a\x65\x63\x74\x20\x70\x61\x74\x68\x20\x27"
.$objectPath)."\x27\x20\x66\x6f\x72\x20\x65\x76\x65\x6e\x74\x20").$currentEvent)
."\x2e"));if (($currentEvent eq $event_sessionAdded)){PhysicSessions::forceCheck
 ();}if (($currentEvent eq $event_sessionRemoved)){PhysicSessions::forceCheck ()
;}setEvent ((""));}elsif (($line=~ /string "(.*)"/ )){(my $objectPath=$1);
Logger::debug (((((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6f\x62\x6a\x65\x63\x74\x20\x70\x61\x74\x68\x20\x27"
.$objectPath)."\x27\x20\x66\x6f\x72\x20\x65\x76\x65\x6e\x74\x20").$currentEvent)
."\x2e"));if (($objectPath eq (""))){setEvent ((""));return (
(0x0475+ 8618-0x261f));}if (($currentEvent eq $event_activeSessionChanged)){
PhysicSessions::forceCheck ();}setEvent ((""));}}sub parseDbusMonitorLine_LOG{(my $line
=shift (@_));if (($line=~ /member=SessionNew/ )){PhysicSessions::forceCheck ();}
elsif (($line=~ /member=SessionRemoved/ )){PhysicSessions::forceCheck ();}elsif 
(($line=~ /object path "(.*)"/ )){(my $objectPath=$1);Logger::debug (((((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6f\x62\x6a\x65\x63\x74\x20\x70\x61\x74\x68\x20\x27"
.$objectPath)."\x27\x20\x66\x6f\x72\x20\x65\x76\x65\x6e\x74\x20").$currentEvent)
."\x2e"));if (($currentEvent eq $event_sessionAdded)){PhysicSessions::forceCheck
 ();}if (($currentEvent eq $event_sessionRemoved)){PhysicSessions::forceCheck ()
;}setEvent ((""));}}sub selectMonitoringMode{if (($monitoringMode ne (""))){
Logger::debug (((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6d\x6f\x64\x65\x20\x73\x65\x74\x20\x74\x6f\x20\x27"
.$monitoringMode)."\x27\x2e"));if (($monitoringMode eq $monitoringMode_noDbus)){
return ((0x0f61+ 3927-0x1eb8));}return ((0x10b3+ 1718-0x1768));}(my (@busNames)=
NXDbus::getSystemBusNames ());foreach my $busName (@busNames){if (
canNameBeUsedToMonitor ($busName)){if (($busName eq $monitoringMode_GDM)){(
$monitoringMode=$busName);Logger::debug (((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6d\x6f\x64\x65\x20\x73\x65\x74\x20\x74\x6f\x20\x27"
.$monitoringMode)."\x27\x2e"));return ((0x1d14+ 1224-0x21db));}elsif (($busName 
eq $monitoringMode_FDM)){($monitoringMode=$busName);Logger::debug (((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6d\x6f\x64\x65\x20\x73\x65\x74\x20\x74\x6f\x20\x27"
.$monitoringMode)."\x27\x2e"));return ((0x0137+ 1679-0x07c5));}elsif (($busName 
eq $monitoringMode_CK)){($monitoringMode=$busName);}elsif ((($busName eq 
$monitoringMode_LOG)and ($monitoringMode ne $monitoringMode_CK))){(
$monitoringMode=$busName);}elsif ((($monitoringMode ne $monitoringMode_CK)and (
$monitoringMode ne $monitoringMode_LOG))){($monitoringMode=$busName);}}}if ((
$monitoringMode ne (""))){Logger::debug (((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6d\x6f\x64\x65\x20\x73\x65\x74\x20\x74\x6f\x20\x27"
.$monitoringMode)."\x27\x2e"));return ((0x1d89+ 891-0x2103));}($monitoringMode=
$monitoringMode_noDbus);return ((0x0294+ 4176-0x12e4));}sub monitoringMode_byLOG
{if (($monitoringMode eq $monitoringMode_LOG)){return ((0x04ab+ 4090-0x14a4));}
return ((0x1312+ 817-0x1643));}sub monitoringMode_byCK{if (($monitoringMode eq 
$monitoringMode_CK)){return ((0x1643+ 3331-0x2345));}return (
(0x0837+ 4430-0x1985));}sub monitoringMode_byGDM{if (($monitoringMode eq 
$monitoringMode_GDM)){return ((0x0405+ 2155-0x0c6f));}return (
(0x11ef+ 551-0x1416));}sub monitoringMode_byFDM{if (($monitoringMode eq 
$monitoringMode_FDM)){return ((0x0277+ 6498-0x1bd8));}return (
(0x0da6+ 4906-0x20d0));}sub checkByDbusDisabled{if (($monitoringMode eq (""))){
return ((0x0e40+ 4674-0x2081));}if (($monitoringMode eq $monitoringMode_noDbus))
{return ((0x03b6+ 8380-0x2471));}return ((0x0d18+ 1318-0x123e));}sub 
canNameBeUsedToMonitor{(my $name=shift (@_));if ((((($name eq $monitoringMode_CK
)or ($name eq $monitoringMode_FDM))or ($name eq $monitoringMode_LOG))or ($name 
eq $monitoringMode_GDM))){return ((0x0ed1+ 1513-0x14b9));}return (
(0x13c3+ 3765-0x2278));}sub setEvent{(my $event=shift (@_));($currentEvent=
$event);}sub isDbusEnabledByConfig{return ($GLOBAL::UseDbusToHandleSystemEvents)
;}"\x3f\x3f\x3f";

==> nomachine-8.10.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXDbusMonitor.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXDbusMonitor;no warnings;require Common::NXShellCommands;require NXDbus
;($monitoringMode_noDbus="\x5f\x5f\x6e\x6f\x44\x42\x75\x73\x5f\x5f");(
$monitoringMode_CK=
"\x6f\x72\x67\x2e\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2e\x43\x6f\x6e\x73\x6f\x6c\x65\x4b\x69\x74"
);($monitoringMode_GDM=
"\x6f\x72\x67\x2e\x67\x6e\x6f\x6d\x65\x2e\x44\x69\x73\x70\x6c\x61\x79\x4d\x61\x6e\x61\x67\x65\x72"
);($monitoringMode_FDM=
"\x6f\x72\x67\x2e\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2e\x44\x69\x73\x70\x6c\x61\x79\x4d\x61\x6e\x61\x67\x65\x72"
);($monitoringMode_LOG=
"\x6f\x72\x67\x2e\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2e\x6c\x6f\x67\x69\x6e\x31"
);($event_sessionAdded="\x53\x65\x73\x73\x69\x6f\x6e\x41\x64\x64\x65\x64");(
$event_sessionRemoved="\x53\x65\x73\x73\x69\x6f\x6e\x52\x65\x6d\x6f\x76\x65\x64"
);($event_activeSessionChanged=
"\x41\x63\x74\x69\x76\x65\x53\x65\x73\x73\x69\x6f\x6e\x43\x68\x61\x6e\x67\x65\x64"
);($monitoringMode=(""));($stdout=(-(0x01a8+ 602-0x0401)));($stdin=(-
(0x1d79+ 248-0x1e70)));($started=(0x1243+ 514-0x1445));($pid=
(0x0c66+ 4565-0x1e3b));($currentEvent=(""));sub startMonitor{if ((not (
isDbusEnabledByConfig ()))){Logger::debug (
"\x44\x42\x75\x73\x20\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x69\x73\x20\x64\x69\x73\x61\x62\x6c\x65\x64\x2e"
);return ((0x174b+ 2842-0x2265));}if ($started){return ((0x0396+ 2536-0x0d7e));}
if (($monitoringMode eq (""))){if ((not (selectMonitoringMode ()))){
Logger::debug (
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x3a\x20\x6e\x6f\x20\x62\x75\x73\x20\x73\x75\x69\x74\x61\x62\x6c\x65\x20\x66\x6f\x72\x20\x6d\x6f\x6e\x69\x74\x6f\x72\x69\x6e\x67\x20\x66\x6f\x75\x6e\x64\x2e"
);return ((0x1068+ 3209-0x1cf1));}}Logger::debug (
"\x53\x74\x61\x72\x74\x69\x6e\x67\x20\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x2e"
);my ($dbusIn);my ($dbusOut);Common::NXCore::nxPipeCreateBi ((\$stdin),(\$dbusIn
));Common::NXCore::nxPipeCreateBi ((\$stdout),(\$dbusOut));if (($monitoringMode 
eq $monitoringMode_CK)){($pid=NXDbus::dbusMonitor ($dbusIn,$dbusOut,
"\x73\x79\x73\x74\x65\x6d","\x73\x69\x67\x6e\x61\x6c",(""),
"\x6f\x72\x67\x2e\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2e\x43\x6f\x6e\x73\x6f\x6c\x65\x4b\x69\x74\x2e\x53\x65\x61\x74"
,("")));}elsif (($monitoringMode eq $monitoringMode_GDM)){($pid=
NXDbus::dbusMonitor ($dbusIn,$dbusOut,"\x73\x79\x73\x74\x65\x6d",
"\x6d\x65\x74\x68\x6f\x64\x5f\x63\x61\x6c\x6c",(""),
"\x6f\x72\x67\x2e\x67\x6e\x6f\x6d\x65\x2e\x44\x69\x73\x70\x6c\x61\x79\x4d\x61\x6e\x61\x67\x65\x72\x2e\x4d\x61\x6e\x61\x67\x65\x72"
,"\x52\x65\x67\x69\x73\x74\x65\x72\x53\x65\x73\x73\x69\x6f\x6e"));}elsif ((
$monitoringMode eq $monitoringMode_FDM)){($pid=NXDbus::dbusMonitor ($dbusIn,
$dbusOut,"\x73\x79\x73\x74\x65\x6d","\x73\x69\x67\x6e\x61\x6c",(""),
"\x6f\x72\x67\x2e\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2e\x44\x69\x73\x70\x6c\x61\x79\x4d\x61\x6e\x61\x67\x65\x72"
,("")));}elsif (($monitoringMode eq $monitoringMode_LOG)){($pid=
NXDbus::dbusMonitor ($dbusIn,$dbusOut,"\x73\x79\x73\x74\x65\x6d",
"\x73\x69\x67\x6e\x61\x6c",(""),
"\x6f\x72\x67\x2e\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2e\x6c\x6f\x67\x69\x6e\x31\x2e\x4d\x61\x6e\x61\x67\x65\x72"
,("")));}if (($pid>(0x01e8+ 2706-0x0c7a))){($started=(0x0104+ 8075-0x208e));
Logger::debug (((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x72\x75\x6e\x6e\x69\x6e\x67\x20\x77\x69\x74\x68\x20\x50\x49\x44\x20"
.$pid)."\x2e"));return ((0x0318+ 8138-0x22e1));}else{Logger::debug (
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6e\x6f\x74\x20\x73\x74\x61\x72\x74\x65\x64\x2e"
);return ((0x132f+ 4500-0x24c3));}}sub getStdout{return ($stdout);}sub isRunning
{return ($started);}sub stopMonitor{Logger::debug (
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x73\x74\x6f\x70\x4d\x6f\x6e\x69\x74\x6f\x72\x2e"
);if (isRunning ()){Logger::debug (((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x73\x65\x6e\x64\x69\x6e\x67\x20\x73\x69\x67\x74\x65\x72\x6d\x20\x74\x6f\x20\x70\x72\x6f\x63\x65\x73\x73\x20\x77\x69\x74\x68\x20\x70\x69\x64\x20\x27"
.$pid)."\x27\x2e"));Common::NXProcess::signalProcessByRestrictedScript ($pid,
Common::NXProcess::getSignalTerm ());if ((Common::NXProcess::nxwaitpid ($pid,
$NXBits::WAIT_UNTRACED,(0x0d1a+ 3707-0x1b90))==$pid)){($pid=(-
(0x05d7+ 187-0x0691)));($started=(0x12a5+ 1607-0x18ec));}else{
Common::NXProcess::signalProcessByRestrictedScript ($pid,
Common::NXProcess::getSignalKill ());if ((Common::NXProcess::nxwaitpid ($pid,
$NXBits::WAIT_UNTRACED,(0x0b48+ 3104-0x1763))==$pid)){($pid=(-
(0x0f6b+ 4345-0x2063)));($started=(0x0317+ 9077-0x268c));}}}}sub 
parseDbusMonitorBuffer{(my $buffer=shift (@_));(my (@lines)=split ( /\n/ ,
$buffer,(0x1049+ 3542-0x1e1f)));foreach my $line (@lines){parseDbusMonitorLine (
$line);}}sub parseDbusMonitorLine{(my $line=shift (@_));Logger::debug (((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x70\x61\x72\x73\x65\x20\x6c\x69\x6e\x65\x20\x27"
.$line)."\x27\x2e"));if (($monitoringMode eq $monitoringMode_CK)){
parseDbusMonitorLine_CK ($line);}elsif (($monitoringMode eq $monitoringMode_LOG)
){parseDbusMonitorLine_LOG ($line);}else{if (($line=~ /member=SessionRemoved/ ))
{PhysicSessions::forceCheck ();}elsif (($line=~ /member=SessionAdded/ )){
PhysicSessions::forceCheck ();}elsif (($line=~ /RegisterSession/ )){
PhysicSessions::forceCheck ();}elsif (($line=~ /object path "(.*)"/ )){(my $objectPath
=$1);Logger::debug (((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6f\x62\x6a\x65\x63\x74\x20\x70\x61\x74\x68\x20\x66\x6f\x72\x20\x65\x76\x65\x6e\x74\x20\x27"
.$objectPath)."\x27\x2e"));}}}sub parseDbusMonitorLine_CK{(my $line=shift (@_));
if (($line=~ /member=SessionAdded/ )){PhysicSessions::forceCheck ();}elsif ((
$line=~ /member=SessionRemoved/ )){PhysicSessions::forceCheck ();}elsif (($line
=~ /member=ActiveSessionChanged/ )){PhysicSessions::forceCheck ();}elsif (($line
=~ /object path "(.*)"/ )){(my $objectPath=$1);Logger::debug (((((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6f\x62\x6a\x65\x63\x74\x20\x70\x61\x74\x68\x20\x27"
.$objectPath)."\x27\x20\x66\x6f\x72\x20\x65\x76\x65\x6e\x74\x20").$currentEvent)
."\x2e"));if (($currentEvent eq $event_sessionAdded)){PhysicSessions::forceCheck
 ();}if (($currentEvent eq $event_sessionRemoved)){PhysicSessions::forceCheck ()
;}setEvent ((""));}elsif (($line=~ /string "(.*)"/ )){(my $objectPath=$1);
Logger::debug (((((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6f\x62\x6a\x65\x63\x74\x20\x70\x61\x74\x68\x20\x27"
.$objectPath)."\x27\x20\x66\x6f\x72\x20\x65\x76\x65\x6e\x74\x20").$currentEvent)
."\x2e"));if (($objectPath eq (""))){setEvent ((""));return (
(0x0c0c+ 6786-0x268e));}if (($currentEvent eq $event_activeSessionChanged)){
PhysicSessions::forceCheck ();}setEvent ((""));}}sub parseDbusMonitorLine_LOG{(my $line
=shift (@_));if (($line=~ /member=SessionNew/ )){PhysicSessions::forceCheck ();}
elsif (($line=~ /member=SessionRemoved/ )){PhysicSessions::forceCheck ();}elsif 
(($line=~ /object path "(.*)"/ )){(my $objectPath=$1);Logger::debug (((((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6f\x62\x6a\x65\x63\x74\x20\x70\x61\x74\x68\x20\x27"
.$objectPath)."\x27\x20\x66\x6f\x72\x20\x65\x76\x65\x6e\x74\x20").$currentEvent)
."\x2e"));if (($currentEvent eq $event_sessionAdded)){PhysicSessions::forceCheck
 ();}if (($currentEvent eq $event_sessionRemoved)){PhysicSessions::forceCheck ()
;}setEvent ((""));}}sub selectMonitoringMode{if (($monitoringMode ne (""))){
Logger::debug (((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6d\x6f\x64\x65\x20\x73\x65\x74\x20\x74\x6f\x20\x27"
.$monitoringMode)."\x27\x2e"));if (($monitoringMode eq $monitoringMode_noDbus)){
return ((0x1718+ 182-0x17ce));}return ((0x0124+ 3115-0x0d4e));}(my (@busNames)=
NXDbus::getSystemBusNames ());foreach my $busName (@busNames){if (
canNameBeUsedToMonitor ($busName)){if (($busName eq $monitoringMode_GDM)){(
$monitoringMode=$busName);Logger::debug (((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6d\x6f\x64\x65\x20\x73\x65\x74\x20\x74\x6f\x20\x27"
.$monitoringMode)."\x27\x2e"));return ((0x15c0+ 765-0x18bc));}elsif (($busName 
eq $monitoringMode_FDM)){($monitoringMode=$busName);Logger::debug (((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6d\x6f\x64\x65\x20\x73\x65\x74\x20\x74\x6f\x20\x27"
.$monitoringMode)."\x27\x2e"));return ((0x0ae3+ 3061-0x16d7));}elsif (($busName 
eq $monitoringMode_CK)){($monitoringMode=$busName);}elsif ((($busName eq 
$monitoringMode_LOG)and ($monitoringMode ne $monitoringMode_CK))){(
$monitoringMode=$busName);}elsif ((($monitoringMode ne $monitoringMode_CK)and (
$monitoringMode ne $monitoringMode_LOG))){($monitoringMode=$busName);}}}if ((
$monitoringMode ne (""))){Logger::debug (((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6d\x6f\x64\x65\x20\x73\x65\x74\x20\x74\x6f\x20\x27"
.$monitoringMode)."\x27\x2e"));return ((0x04bf+ 2976-0x105e));}($monitoringMode=
$monitoringMode_noDbus);return ((0x00b1+ 5230-0x151f));}sub monitoringMode_byLOG
{if (($monitoringMode eq $monitoringMode_LOG)){return ((0x0de9+ 908-0x1174));}
return ((0x016c+ 9010-0x249e));}sub monitoringMode_byCK{if (($monitoringMode eq 
$monitoringMode_CK)){return ((0x0323+ 1367-0x0879));}return (
(0x045c+ 1816-0x0b74));}sub monitoringMode_byGDM{if (($monitoringMode eq 
$monitoringMode_GDM)){return ((0x1418+ 644-0x169b));}return (
(0x0061+ 1605-0x06a6));}sub monitoringMode_byFDM{if (($monitoringMode eq 
$monitoringMode_FDM)){return ((0x05da+ 5567-0x1b98));}return (
(0x08eb+ 6977-0x242c));}sub checkByDbusDisabled{if (($monitoringMode eq (""))){
return ((0x0211+ 2053-0x0a15));}if (($monitoringMode eq $monitoringMode_noDbus))
{return ((0x0115+ 3818-0x0ffe));}return ((0x1715+ 526-0x1923));}sub 
canNameBeUsedToMonitor{(my $name=shift (@_));if ((((($name eq $monitoringMode_CK
)or ($name eq $monitoringMode_FDM))or ($name eq $monitoringMode_LOG))or ($name 
eq $monitoringMode_GDM))){return ((0x146d+ 1266-0x195e));}return (
(0x0124+ 9083-0x249f));}sub setEvent{(my $event=shift (@_));($currentEvent=
$event);}sub isDbusEnabledByConfig{return ($GLOBAL::UseDbusToHandleSystemEvents)
;}"\x3f\x3f\x3f";
